package com.ruoyi.system.mapper;

import java.util.List;
import com.ruoyi.system.domain.InterestsNumberTable;
import org.apache.ibatis.annotations.Param;

/**
 * 商户权益次数记录Mapper接口
 * 
 * @author ruoyi
 * @date 2022-07-08
 */
public interface InterestsNumberTableMapper 
{
    /**
     * 查询商户权益次数记录
     * 
     * @param id 商户权益次数记录主键
     * @return 商户权益次数记录
     */
    public InterestsNumberTable selectInterestsNumberTableById(Long id);

    /**
     * 查询商户权益次数记录列表
     * 
     * @param interestsNumberTable 商户权益次数记录
     * @return 商户权益次数记录集合
     */
    public List<InterestsNumberTable> selectInterestsNumberTableList(InterestsNumberTable interestsNumberTable);

    /**
     * 新增商户权益次数记录
     * 
     * @param interestsNumberTable 商户权益次数记录
     * @return 结果
     */
    public int insertInterestsNumberTable(InterestsNumberTable interestsNumberTable);

    /**
     * 修改商户权益次数记录
     * 
     * @param interestsNumberTable 商户权益次数记录
     * @return 结果
     */
    public int updateInterestsNumberTable(InterestsNumberTable interestsNumberTable);

    /**
     * 删除商户权益次数记录
     * 
     * @param id 商户权益次数记录主键
     * @return 结果
     */
    public int deleteInterestsNumberTableById(Long id);

    /**
     * 批量删除商户权益次数记录
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteInterestsNumberTableByIds(Long[] ids);

    InterestsNumberTable selectInterestsNumberTable(InterestsNumberTable interestsNumberTable);

    InterestsNumberTable selectInterestsNumberTableByPolicyId(@Param("menuId") Long menuId, @Param("creditLevel")String creditLevel);
}
